==> marketplace-constants-0.1.4.9.tar.gz: marketplace-constants-0.1.4.9/mpconstants/regions/hu.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Egyes\xfclt Arab Emir\xe1tusok',
 u'af': u'Afganiszt\xe1n',
 u'ag': u'Antigua \xe9s Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Alb\xe1nia',
 u'am': u'\xd6rm\xe9nyorsz\xe1g',
 u'an': u'Holland-Antill\xe1k',
 u'ao': u'Angola',
 u'aq': u'Antarktisz',
 u'ar': u'Argent\xedna',
 u'as': u'Amerikai Szamoa',
 u'at': u'Ausztria',
 u'au': u'Ausztr\xe1lia',
 u'aw': u'Aruba',
 u'ax': u'\\u00c5land-szigetek',
 u'az': u'Azerbajdzs\xe1n',
 u'ba': u'Bosznia-Hercegovina',
 u'bb': u'Barbados',
 u'bd': u'Banglades',
 u'be': u'Belgium',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulg\xe1ria',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\\u00e9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bol\xedvia',
 u'br': u'Braz\xedlia',
 u'bs': u'Bahama-szigetek',
 u'bt': u'Bhut\xe1n',
 u'bv': u'Bouvet-sziget',
 u'bw': u'Botswana',
 u'by': u'Feh\xe9roroszorsz\xe1g',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Cocos- (Keeling) szigetek',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'K\xf6z\xe9p-Afrikai K\xf6zt\xe1rsas\xe1g',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Sv\xe1jc',
 u'ci': u'Elef\xe1ntcsontpart',
 u'ck': u'Cook-szigetek',
 u'cl': u'Chile',
 u'cm': u'Kamerun',
 u'cn': u'K\xedna',
 u'co': u'Kolumbia',
 u'cr': u'Costa Rica',
 u'cu': u'Kuba',
 u'cv': u'Z\xf6ldfoki-szigetek',
 u'cx': u'Kar\xe1csony-szigetek',
 u'cy': u'Ciprus',
 u'cz': u'Cseh K\xf6zt\xe1rsas\xe1g',
 u'de': u'N\xe9metorsz\xe1g',
 u'dj': u'Dzsibuti',
 u'dk': u'D\xe1nia',
 u'dm': u'Dominikai K\xf6z\xf6ss\xe9g',
 u'do': u'Dominikai K\xf6zt\xe1rsas\xe1g',
 u'dz': u'Alg\xe9ria',
 u'ec': u'Ecuador',
 u'ee': u'\xc9sztorsz\xe1g',
 u'eg': u'Egyiptom',
 u'eh': u'Nyugat-Szahara',
 u'er': u'Eritrea',
 u'es': u'Spanyolorsz\xe1g',
 u'et': u'Eti\xf3pia',
 u'fi': u'Finnorsz\xe1g',
 u'fj': u'Fidzsi-szigetek',
 u'fk': u'Falkland-szigetek',
 u'fm': u'Mikron\xe9zia',
 u'fo': u'Fer\xf6er-szigetek',
 u'fr': u'Franciaorsz\xe1g',
 u'ga': u'Gabon',
 u'gb': u'Egyes\xfclt Kir\xe1lys\xe1g',
 u'gd': u'Grenada',
 u'ge': u'Gr\xfazia',
 u'gf': u'Francia Guiana',
 u'gg': u'Guernsey',
 u'gh': u'Gh\xe1na',
 u'gi': u'Gibralt\xe1r',
 u'gl': u'Gr\xf6nland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Egyenl\xedt\u0151i Guinea',
 u'gr': u'G\xf6r\xf6gorsz\xe1g',
 u'gs': u'D\xe9l-Georgia \xe9s D\xe9li Sandwich-szigetek',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard-sziget \xe9s McDonald-szigetek',
 u'hn': u'Honduras',
 u'hr': u'Horv\xe1torsz\xe1g',
 u'ht': u'Haiti',
 u'hu': u'Magyarorsz\xe1g',
 u'id': u'Indon\xe9zia',
 u'ie': u'\xcdrorsz\xe1g',
 u'il': u'Izrael',
 u'im': u'Man szigete',
 u'in': u'India',
 u'io': u'Britindiai \xf3ce\xe1ni ter\xfclet',
 u'iq': u'Irak',
 u'ir': u'Ir\xe1n',
 u'is': u'Izland',
 u'it': u'Olaszorsz\xe1g',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jord\xe1nia',
 u'jp': u'Jap\xe1n',
 u'ke': u'Kenya',
 u'kg': u'Kirgiziszt\xe1n',
 u'kh': u'Kambodzsa',
 u'ki': u'Kiribati',
 u'km': u'Comoro-szigetek',
 u'kn': u'Saint Kitts \xe9s Nevis',
 u'kp': u'\xc9szak-Korea',
 u'kr': u'D\xe9l-Korea',
 u'kw': u'Kuvait',
 u'ky': u'Kajm\xe1n-szigetek',
 u'kz': u'Kazahszt\xe1n',
 u'la': u'Laosz',
 u'lb': u'Libanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Litv\xe1nia',
 u'lu': u'Luxemburg',
 u'lv': u'Lettorsz\xe1g',
 u'ly': u'L\xedbia',
 u'ma': u'Marokk\xf3',
 u'mc': u'Monaco',
 u'md': u'Moldova',
 u'me': u'Montenegr\xf3',
 u'mf': u'Saint Martin',
 u'mg': u'Madagaszk\xe1r',
 u'mh': u'Marshall-szigetek',
 u'mk': u'Maced\xf3nia',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mong\xf3lia',
 u'mo': u'Macao',
 u'mp': u'\xc9szaki Mariana-szigetek',
 u'mq': u'Martinique',
 u'mr': u'Maurit\xe1nia',
 u'ms': u'Montserrat',
 u'mt': u'M\xe1lta',
 u'mu': u'Mauritius',
 u'mv': u'Mald\xedv-szigetek',
 u'mw': u'Malawi',
 u'mx': u'Mexik\xf3',
 u'my': u'Malajzia',
 u'mz': u'Mozambik',
 u'na': u'Nam\xedbia',
 u'nc': u'\xdaj-Kaled\xf3nia',
 u'ne': u'Niger',
 u'nf': u'Norfolk-sziget',
 u'ng': u'Nig\xe9ria',
 u'ni': u'Nicaragua',
 u'nl': u'Hollandia',
 u'no': u'Norv\xe9gia',
 u'np': u'Nep\xe1l',
 u'nr': u'nauru',
 u'nu': u'Niue',
 u'nz': u'\xdaj-Z\xe9land',
 u'om': u'Om\xe1n',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Francia Polin\xe9zia',
 u'pg': u'P\xe1pua \xdaj-Guinea',
 u'ph': u'F\xfcl\xf6p-szigetek',
 u'pk': u'Pakiszt\xe1n',
 u'pl': u'Lengyelorsz\xe1g',
 u'pm': u'Saint Pierre \xe9s Miquelon',
 u'pn': u'Pitcairn-szigetek',
 u'pr': u'Puerto Rico',
 u'ps': u'Megsz\xe1llt palesztin ter\xfclet',
 u'pt': u'Portug\xe1lia',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Katar',
 u're': u'Reunion',
 u'ro': u'Rom\xe1nia',
 u'rs': u'Szerbia',
 u'ru': u'Orosz F\xf6der\xe1ci\xf3',
 u'rw': u'Ruanda',
 u'sa': u'Sza\xfad-Ar\xe1bia',
 u'sb': u'Salamon-szigetek',
 u'sc': u'Seychell-szigetek',
 u'sd': u'Szud\xe1n',
 u'se': u'Sv\xe9dorsz\xe1g',
 u'sg': u'Szingap\xfar',
 u'sh': u'Saint Helena',
 u'si': u'Szlov\xe9nia',
 u'sj': u'Svalbard \xe9s Jan Mayen',
 u'sk': u'Szlov\xe1kia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Szeneg\xe1l',
 u'so': u'Szom\xe1lia',
 u'sr': u'Suriname',
 u'st': u'Sao Tome \xe9s Principe',
 u'sv': u'El Salvador',
 u'sy': u'Sz\xedria',
 u'sz': u'Szv\xe1zif\xf6ld',
 u'tc': u'Turks \xe9s Caicos-szigetek',
 u'td': u'Cs\xe1d',
 u'tf': u'Francia d\xe9li ter\xfcletek',
 u'tg': u'Togo',
 u'th': u'Thaif\xf6ld',
 u'tj': u'T\xe1dzsikiszt\xe1n',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'T\xfcrkmeniszt\xe1n',
 u'tn': u'Tun\xe9zia',
 u'to': u'Tonga',
 u'tr': u'T\xf6r\xf6korsz\xe1g',
 u'tt': u'Trinidad \xe9s Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Tajvan',
 u'tz': u'Tanz\xe1nia',
 u'ua': u'Ukrajna',
 u'ug': u'Uganda',
 u'um': u'Egyes\xfclt \xc1llamok k\xfcls\u0151 szigetei',
 u'us': u'Egyes\xfclt \xc1llamok',
 u'uy': u'Uruguay',
 u'uz': u'\xdczbegiszt\xe1n',
 u'va': u'Vatik\xe1nv\xe1ros',
 u'vc': u'Saint Vincent \xe9s Grenadine-szigetek',
 u've': u'Venezuela',
 u'vg': u'Brit Virgin-szigetek',
 u'vi': u'U.S. Virgin-szigetek',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis \xe9s Futuna',
 u'ws': u'Szamoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'D\xe9l-Afrikai K\xf6zt\xe1rsas\xe1g',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}

==> marketplace-constants-0.3.2.tar.gz: marketplace-constants-0.3.2/mpconstants/regions/hu.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Egyes\xfclt Arab Emir\xe1tusok',
 u'af': u'Afganiszt\xe1n',
 u'ag': u'Antigua \xe9s Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Alb\xe1nia',
 u'am': u'\xd6rm\xe9nyorsz\xe1g',
 u'an': u'Holland-Antill\xe1k',
 u'ao': u'Angola',
 u'aq': u'Antarktisz',
 u'ar': u'Argent\xedna',
 u'as': u'Amerikai Szamoa',
 u'at': u'Ausztria',
 u'au': u'Ausztr\xe1lia',
 u'aw': u'Aruba',
 u'ax': u'\xc5land-szigetek',
 u'az': u'Azerbajdzs\xe1n',
 u'ba': u'Bosznia-Hercegovina',
 u'bb': u'Barbados',
 u'bd': u'Banglades',
 u'be': u'Belgium',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulg\xe1ria',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bol\xedvia',
 u'br': u'Braz\xedlia',
 u'bs': u'Bahama-szigetek',
 u'bt': u'Bhut\xe1n',
 u'bv': u'Bouvet-sziget',
 u'bw': u'Botswana',
 u'by': u'Feh\xe9roroszorsz\xe1g',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Cocos- (Keeling) szigetek',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'K\xf6z\xe9p-Afrikai K\xf6zt\xe1rsas\xe1g',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Sv\xe1jc',
 u'ci': u'Elef\xe1ntcsontpart',
 u'ck': u'Cook-szigetek',
 u'cl': u'Chile',
 u'cm': u'Kamerun',
 u'cn': u'K\xedna',
 u'co': u'Kolumbia',
 u'cr': u'Costa Rica',
 u'cu': u'Kuba',
 u'cv': u'Z\xf6ldfoki-szigetek',
 u'cx': u'Kar\xe1csony-szigetek',
 u'cy': u'Ciprus',
 u'cz': u'Cseh K\xf6zt\xe1rsas\xe1g',
 u'de': u'N\xe9metorsz\xe1g',
 u'dj': u'Dzsibuti',
 u'dk': u'D\xe1nia',
 u'dm': u'Dominikai K\xf6z\xf6ss\xe9g',
 u'do': u'Dominikai K\xf6zt\xe1rsas\xe1g',
 u'dz': u'Alg\xe9ria',
 u'ec': u'Ecuador',
 u'ee': u'\xc9sztorsz\xe1g',
 u'eg': u'Egyiptom',
 u'eh': u'Nyugat-Szahara',
 u'er': u'Eritrea',
 u'es': u'Spanyolorsz\xe1g',
 u'et': u'Eti\xf3pia',
 u'fi': u'Finnorsz\xe1g',
 u'fj': u'Fidzsi-szigetek',
 u'fk': u'Falkland-szigetek',
 u'fm': u'Mikron\xe9zia',
 u'fo': u'Fer\xf6er-szigetek',
 u'fr': u'Franciaorsz\xe1g',
 u'ga': u'Gabon',
 u'gb': u'Egyes\xfclt Kir\xe1lys\xe1g',
 u'gd': u'Grenada',
 u'ge': u'Gr\xfazia',
 u'gf': u'Francia Guiana',
 u'gg': u'Guernsey',
 u'gh': u'Gh\xe1na',
 u'gi': u'Gibralt\xe1r',
 u'gl': u'Gr\xf6nland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Egyenl\xedt\u0151i Guinea',
 u'gr': u'G\xf6r\xf6gorsz\xe1g',
 u'gs': u'D\xe9l-Georgia \xe9s D\xe9li Sandwich-szigetek',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard-sziget \xe9s McDonald-szigetek',
 u'hn': u'Honduras',
 u'hr': u'Horv\xe1torsz\xe1g',
 u'ht': u'Haiti',
 u'hu': u'Magyarorsz\xe1g',
 u'id': u'Indon\xe9zia',
 u'ie': u'\xcdrorsz\xe1g',
 u'il': u'Izrael',
 u'im': u'Man szigete',
 u'in': u'India',
 u'io': u'Britindiai \xf3ce\xe1ni ter\xfclet',
 u'iq': u'Irak',
 u'ir': u'Ir\xe1n',
 u'is': u'Izland',
 u'it': u'Olaszorsz\xe1g',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jord\xe1nia',
 u'jp': u'Jap\xe1n',
 u'ke': u'Kenya',
 u'kg': u'Kirgiziszt\xe1n',
 u'kh': u'Kambodzsa',
 u'ki': u'Kiribati',
 u'km': u'Comoro-szigetek',
 u'kn': u'Saint Kitts \xe9s Nevis',
 u'kp': u'\xc9szak-Korea',
 u'kr': u'D\xe9l-Korea',
 u'kw': u'Kuvait',
 u'ky': u'Kajm\xe1n-szigetek',
 u'kz': u'Kazahszt\xe1n',
 u'la': u'Laosz',
 u'lb': u'Libanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Litv\xe1nia',
 u'lu': u'Luxemburg',
 u'lv': u'Lettorsz\xe1g',
 u'ly': u'L\xedbia',
 u'ma': u'Marokk\xf3',
 u'mc': u'Monaco',
 u'md': u'Moldova',
 u'me': u'Montenegr\xf3',
 u'mf': u'Saint Martin',
 u'mg': u'Madagaszk\xe1r',
 u'mh': u'Marshall-szigetek',
 u'mk': u'Maced\xf3nia',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mong\xf3lia',
 u'mo': u'Macao',
 u'mp': u'\xc9szaki Mariana-szigetek',
 u'mq': u'Martinique',
 u'mr': u'Maurit\xe1nia',
 u'ms': u'Montserrat',
 u'mt': u'M\xe1lta',
 u'mu': u'Mauritius',
 u'mv': u'Mald\xedv-szigetek',
 u'mw': u'Malawi',
 u'mx': u'Mexik\xf3',
 u'my': u'Malajzia',
 u'mz': u'Mozambik',
 u'na': u'Nam\xedbia',
 u'nc': u'\xdaj-Kaled\xf3nia',
 u'ne': u'Niger',
 u'nf': u'Norfolk-sziget',
 u'ng': u'Nig\xe9ria',
 u'ni': u'Nicaragua',
 u'nl': u'Hollandia',
 u'no': u'Norv\xe9gia',
 u'np': u'Nep\xe1l',
 u'nr': u'nauru',
 u'nu': u'Niue',
 u'nz': u'\xdaj-Z\xe9land',
 u'om': u'Om\xe1n',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Francia Polin\xe9zia',
 u'pg': u'P\xe1pua \xdaj-Guinea',
 u'ph': u'F\xfcl\xf6p-szigetek',
 u'pk': u'Pakiszt\xe1n',
 u'pl': u'Lengyelorsz\xe1g',
 u'pm': u'Saint Pierre \xe9s Miquelon',
 u'pn': u'Pitcairn-szigetek',
 u'pr': u'Puerto Rico',
 u'ps': u'Megsz\xe1llt palesztin ter\xfclet',
 u'pt': u'Portug\xe1lia',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Katar',
 u're': u'Reunion',
 u'ro': u'Rom\xe1nia',
 u'rs': u'Szerbia',
 u'ru': u'Orosz F\xf6der\xe1ci\xf3',
 u'rw': u'Ruanda',
 u'sa': u'Sza\xfad-Ar\xe1bia',
 u'sb': u'Salamon-szigetek',
 u'sc': u'Seychell-szigetek',
 u'sd': u'Szud\xe1n',
 u'se': u'Sv\xe9dorsz\xe1g',
 u'sg': u'Szingap\xfar',
 u'sh': u'Saint Helena',
 u'si': u'Szlov\xe9nia',
 u'sj': u'Svalbard \xe9s Jan Mayen',
 u'sk': u'Szlov\xe1kia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Szeneg\xe1l',
 u'so': u'Szom\xe1lia',
 u'sr': u'Suriname',
 u'st': u'Sao Tome \xe9s Principe',
 u'sv': u'El Salvador',
 u'sy': u'Sz\xedria',
 u'sz': u'Szv\xe1zif\xf6ld',
 u'tc': u'Turks \xe9s Caicos-szigetek',
 u'td': u'Cs\xe1d',
 u'tf': u'Francia d\xe9li ter\xfcletek',
 u'tg': u'Togo',
 u'th': u'Thaif\xf6ld',
 u'tj': u'T\xe1dzsikiszt\xe1n',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'T\xfcrkmeniszt\xe1n',
 u'tn': u'Tun\xe9zia',
 u'to': u'Tonga',
 u'tr': u'T\xf6r\xf6korsz\xe1g',
 u'tt': u'Trinidad \xe9s Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Tajvan',
 u'tz': u'Tanz\xe1nia',
 u'ua': u'Ukrajna',
 u'ug': u'Uganda',
 u'um': u'Egyes\xfclt \xc1llamok k\xfcls\u0151 szigetei',
 u'us': u'Egyes\xfclt \xc1llamok',
 u'uy': u'Uruguay',
 u'uz': u'\xdczbegiszt\xe1n',
 u'va': u'Vatik\xe1nv\xe1ros',
 u'vc': u'Saint Vincent \xe9s Grenadine-szigetek',
 u've': u'Venezuela',
 u'vg': u'Brit Virgin-szigetek',
 u'vi': u'U.S. Virgin-szigetek',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis \xe9s Futuna',
 u'ws': u'Szamoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'D\xe9l-Afrikai K\xf6zt\xe1rsas\xe1g',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}
